import React, { useEffect, useRef } from "react";
import * as d3 from 'd3';

const Bar = ({ data, width, height }: any) => {
    const svgRef: any = useRef<SVGSVGElement>(null);

    useEffect(() => {
        const margin = { top: 10, right: 10, bottom: 20, left: 40 };
        console.log(data)

        const svg = d3
            .select(svgRef.current);

        const everything = svg.selectAll("*");
        everything.remove();

        const xScale = d3
            .scaleBand()
            .domain(data.map((d: any) => d.date))
            .range([0, width - margin.left - margin.right])
            .padding(0.26);

        const X = d3
            .axisBottom(xScale);

        svg
            .append('g')
            .attr('transform', `translate(0, ${height - margin.top - margin.bottom})`)
            .call(X);

        const yScale = d3.scaleLinear()
            .domain([0, Math.max(...data.map((d: any) => d.numberSales))])
            .range([height - margin.top - margin.bottom, 0])
            .nice();

        const Y = d3
            .axisLeft(yScale)
            .ticks(6)
            .tickSize(-(width - margin.left - margin.right));

        svg
            .append('g')
            .call(Y);

        svg
            .selectAll('.bar')
            .data(data)
            .enter()
            .append('rect')
            .attr('class', 'bar')
            .attr('x', (d: any, i: number) => i * 45)
            .attr('y', height - margin.top - margin.bottom)
            .attr('width', 40);

    }, []);

    return (
        <svg ref={svgRef} width={width} height={height} />
    );
};

export default function BarChart(props: any) {

    return (
        <div>
            <h1>Affichage des données par un diagramme à barre</h1>
            <div style={{ marginLeft: 10, }}>
                <Bar data={props.data} width={props.width} height={props.height} />
            </div>
        </div>
    )
}